@@ -23,22 +23,45 @@
 #ifndef _DATA_H
 #define _DATA_H
 
-#include "nv_tvchip.h"
+#include "tv_chip.h"
+
+/* init and setup must use a copy of the values from the database,
+   otherwise the database will change. */
 
 typedef struct {
-  NVMode *modes;
-  void (*init) (NVSystem system, NVTvRegs *r);
-  void (*defaults) (NVSettings *s);
-  void (*setup) (NVSettings *s, NVCrtRegs *c, NVTvRegs *r);
-  void (*clamp) (NVSettings *s);
+  TVMode* (*modes) (void);
+  void (*defaults) (TVSettings *s);
+  void (*setup) (TVSettings *s, TVRegs *r);
+  void (*clamp) (TVSettings *s, TVRegs *r);
+  void (*calc) (TVSystem system, int hres, int vres, double hoc, double voc, 
+		TVRegs *r);
 } DataFunc;
 
+typedef void (*make_vidmode) (int hdisplay, int hsyncstart, int hsyncend, 
+  int htotal, int vdisplay, int vsyncstart, int vsyncend, int vtotal, 
+  int dotclock, TVCrtcRegs *crt);
+
+typedef struct {
+  make_vidmode make;
+} DataCardFunc;
+
 int data_clamp (int val, int size, int ticks[]);
 int data_pick (int val, int size, int ticks[]);
 
-NVMode *data_find (NVMode *modes, NVSystem system, 
+TVMode *data_find (TVMode *modes, TVSystem system, 
   int res_x, int res_y, char *size);
 
-DataFunc *data_func (NVTvChip chip);
+TVMode *data_findNearest (TVMode *modes, TVSystem system, 
+  int res_x, int res_y, double hoc, double voc);
 
-#endif /* _DATA_BT_H */
+int data_listModes (TVMode *modes, TVSystem system, TVMode *(list[]));
+
+void data_calc_null (TVSystem system, int hres, int vres, 
+   double hoc, double voc, TVRegs *r);
+
+DataFunc *data_func (CardType card, TVChip chip);
+DataCardFunc *data_card_func (CardType card);
+
+extern DataFunc null_func;
+
+#endif /* _DATA_H */
