@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86PciInfo.h,v 1.83.2.1 2001/02/15 16:01:40 martin Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86PciInfo.h,v 1.97 2001/05/10 21:14:54 dawes Exp $ */
 /*
  * PCI Probe
  *
@@ -35,6 +35,9 @@
  * 
  */
 
+/* Added some more NVidia entries.  - Dirk Thierbach <dthierbach@gmx.de> */
+/* Added Intel 810/815/830 entries. - Dirk Thierbach <dthierbach@gmx.de> */
+
 #ifndef _XF86_PCIINFO_H
 #define _XF86_PCIINFO_H
 
@@ -150,6 +153,7 @@
 #define PCI_VENDOR_TRITECH	0x1292
 #define PCI_VENDOR_NVIDIA_SGS	0x12d2
 #define PCI_VENDOR_NETGEAR	0x1385
+#define PCI_VENDOR_VMWARE	0x15AD
 #define PCI_VENDOR_SYMPHONY	0x1C1C
 #define PCI_VENDOR_TEKRAM_2	0x1DE1
 #define PCI_VENDOR_3DLABS	0x3D3D
@@ -233,11 +237,13 @@
 #define PCI_CHIP_RAGE128ML	0x4D4C
 #define PCI_CHIP_RAGE128PD	0x5044
 #define PCI_CHIP_RAGE128PF	0x5046
+#define PCI_CHIP_RAGE128PP	0x5050
 #define PCI_CHIP_RAGE128PR	0x5052
 #define PCI_CHIP_RADEON_QD	0x5144
 #define PCI_CHIP_RADEON_QE	0x5145
 #define PCI_CHIP_RADEON_QF	0x5146
 #define PCI_CHIP_RADEON_QG	0x5147
+#define PCI_CHIP_RADEON_VE	0x5159
 #define PCI_CHIP_RAGE128RE	0x5245
 #define PCI_CHIP_RAGE128RF	0x5246
 #define PCI_CHIP_RAGE128RG	0x5247
@@ -259,6 +265,7 @@
 /* Avance Logic */
 #define PCI_CHIP_ALG2064	0x2064
 #define PCI_CHIP_ALG2301	0x2301
+#define PCI_CHIP_ALG2501	0x2501
 
 /* NS */
 #define PCI_CHIP_87415		0x0002
@@ -340,6 +347,8 @@
 #define PCI_CHIP_9750		0x9750
 #define PCI_CHIP_9850		0x9850
 #define PCI_CHIP_9880		0x9880
+#define PCI_CHIP_9910		0x9910
+#define PCI_CHIP_9930		0x9930
 
 /* ALI */
 #define PCI_CHIP_M1435		0x1435
@@ -404,7 +413,8 @@
 #define PCI_CHIP_SIS300		0x0300
 #define PCI_CHIP_SIS630		0x6300
 #define PCI_CHIP_SIS540		0x5300
-
+/* Agregado por Carlos Duclos & Manuel Jander */
+#define PCI_CHIP_SIS82C204	0x0204
 /* HP */
 #define PCI_CHIP_J2585A		0x1030
 #define PCI_CHIP_J2585B		0x1031
@@ -474,8 +484,8 @@
 #define PCI_CHIP_UTNT2		0x0029
 #define PCI_CHIP_VTNT2		0x002C
 #define PCI_CHIP_UVTNT2		0x002D
-#define PCI_CHIP_TNT2_A         0x002E
-#define PCI_CHIP_TNT2_B         0x002F
+#define PCI_CHIP_TNT2_A		0x002E
+#define PCI_CHIP_TNT2_B		0x002F
 #define PCI_CHIP_ITNT2		0x00A0
 #define PCI_CHIP_GEFORCE256     0x0100
 #define PCI_CHIP_GEFORCEDDR     0x0101
@@ -485,31 +495,74 @@
 #define PCI_CHIP_GEFORCE2GO	0x0112
 #define PCI_CHIP_QUADRO2MXR     0x0113
 #define PCI_CHIP_GEFORCE2GTS    0x0150
-#define PCI_CHIP_GEFORCE2GTS_1  0x0151
+#define PCI_CHIP_GEFORCE2TI     0x0151
 #define PCI_CHIP_GEFORCE2ULTRA  0x0152
 #define PCI_CHIP_QUADRO2PRO     0x0153
-#define PCI_CHIP_GEFORCE3       0x0200
-#define PCI_CHIP_GEFORCE3_1     0x0201
-#define PCI_CHIP_GEFORCE3_2     0x0202
-#define PCI_CHIP_GEFORCE3_3     0x0203
+#define PCI_CHIP_GEFORCE4MX_460		0x0170 
+#define PCI_CHIP_GEFORCE4MX_440         0x0171 
+#define PCI_CHIP_GEFORCE4MX_420         0x0172 
+#define PCI_CHIP_GEFORCE4MX_440SE       0x0173
+#define PCI_CHIP_GEFORCE4GO_440         0x0174 
+#define PCI_CHIP_GEFORCE4GO_420         0x0175 
+#define PCI_CHIP_GEFORCE4GO_420_32M     0x0176 
+#define PCI_CHIP_GEFORCE4GO_460         0x0177 
+#define PCI_CHIP_QUADRO4XGL_500         0x0178 
+#define PCI_CHIP_GEFORCE4GO_440_64M     0x0179 
+#define PCI_CHIP_QUADRO4NVS             0x017A 
+#define PCI_CHIP_QUADRO4XGL_550         0x017B 
+#define PCI_CHIP_QUADRO4GOGL_500        0x017C 
+#define	PCI_CHIP_GEFORCE4GO_410_16M     0x017D
+#define	PCI_CHIP_GEFORCE4MX_440_AGP8X   0x0181
+#define	PCI_CHIP_GEFORCE4MX_440SE_AGP8X 0x0182
+#define	PCI_CHIP_GEFORCE4MX_420_AGP8X   0x0183
+#define	PCI_CHIP_QUADRO4_XGL_580        0x0188
+#define	PCI_CHIP_QUADRO4_NVS_280        0x018A
+#define	PCI_CHIP_QUADRO4_XGL_380        0x018B
+#define PCI_CHIP_GEFORCE2GPU            0x01A0 
+#define PCI_CHIP_GEFORCE4GPU            0x01F0
+#define PCI_CHIP_GEFORCE3               0x0200
+#define PCI_CHIP_GEFORCE3TI_200         0x0201
+#define PCI_CHIP_GEFORCE3TI_500         0x0202
+#define PCI_CHIP_QUADRO_DDC             0x0203
+#define PCI_CHIP_GEFORCE4TI_4600        0x0250 
+#define PCI_CHIP_GEFORCE4TI_4400        0x0251 
+#define PCI_CHIP_GEFORCE4TI_4200        0x0253 
+#define PCI_CHIP_QUADRO4XGL_900         0x0258 
+#define PCI_CHIP_QUADRO4XGL_750         0x0259 
+#define PCI_CHIP_QUADRO4XGL_700         0x025B 
+#define PCI_CHIP_GEFORCE4TI_4800        0x0280
+#define PCI_CHIP_GEFORCE4TI_4200_AGP8X  0x0281
+#define PCI_CHIP_GEFORCE4TI_4800SE      0x0282
+#define PCI_CHIP_GEFORCE4GO_4200        0x0286
+#define PCI_CHIP_QUADRO4XGL_980         0x0288
+#define PCI_CHIP_QUADRO4XGL_780         0x0289
+#define PCI_CHIP_QUADRO4GOGL_700        0x028C
+#define PCI_CHIP_GEFORCE3_MCPX	        0x02A0 /* XBox */
 
 
 /* NVIDIA & SGS */
 #define PCI_CHIP_RIVA128	0x0018
 
+/* IMS */
+#define PCI_CHIP_IMSTT128	0x9128
+#define PCI_CHIP_IMSTT3D	0x9135
+
 /* Alliance Semiconductor */
 #define PCI_CHIP_AP6410		0x3210
 #define PCI_CHIP_AP6422		0x6422
 #define PCI_CHIP_AT24		0x6424
 #define PCI_CHIP_AT3D		0x643D
 
-/* 3Dfx Interactive */
+/* 3dfx Interactive */
 #define PCI_CHIP_VOODOO_GRAPHICS 0x0001
 #define PCI_CHIP_VOODOO2	0x0002
 #define PCI_CHIP_BANSHEE	0x0003
 #define PCI_CHIP_VOODOO3	0x0005
 #define PCI_CHIP_VOODOO5	0x0009
 
+#define PCI_CARD_VOODOO3_2000	0x0036
+#define PCI_CARD_VOODOO3_3000	0x003a
+
 /* Rendition */
 #define PCI_CHIP_V1000		0x0001
 #define PCI_CHIP_V2x00		0x2000
@@ -524,6 +577,10 @@
 #define PCI_CHIP_GAMMA		0x0008
 #define PCI_CHIP_PERMEDIA2V	0x0009
 #define PCI_CHIP_PERMEDIA3	0x000A
+#define PCI_CHIP_PERMEDIA4	0x000C
+#define PCI_CHIP_R4		0x000D
+#define PCI_CHIP_GAMMA2		0x000E
+#define PCI_CHIP_R4ALT		0x0011
 
 /* S3 */
 #define PCI_CHIP_PLATO		0x0551
@@ -590,6 +647,8 @@
 #define PCI_CHIP_I810_E			0x7125
 #define PCI_CHIP_I740_AGP		0x7800
 
+#define PCI_CHIP_I830		0x3577
+
 /* Silicon Motion Inc. */
 #define PCI_CHIP_SMI910		0x910
 #define PCI_CHIP_SMI810		0x810
@@ -598,6 +657,10 @@
 #define PCI_CHIP_SMI712		0x712
 #define PCI_CHIP_SMI720		0x720
 
+/* VMware */
+#define PCI_CHIP_VMWARE0405		0x0405
+#define PCI_CHIP_VMWARE0710		0x0710
+
 /*
  * first the VendorId - VendorName mapping
  */
@@ -699,7 +762,7 @@ static SymTabRec xf86PCIVendorNameInfoData[] = {
     {PCI_VENDOR_RICOH,	"Ricoh"},
     {PCI_VENDOR_ZEINET,	"Zeinet"},
     {PCI_VENDOR_LITEON,	"Lite-On"},
-    {PCI_VENDOR_3DFX,	"3Dfx Interactive"},
+    {PCI_VENDOR_3DFX,	"3dfx Interactive"},
     {PCI_VENDOR_SIGMADESIGNS, "Sigma Designs"},
     {PCI_VENDOR_ENSONIQ, "Ensoniq"},
     {PCI_VENDOR_ROCKWELL, "Rockwell"},
@@ -718,6 +781,7 @@ static SymTabRec xf86PCIVendorNameInfoData[] = {
     {PCI_VENDOR_ARK,	"ARK Logic"},
     {PCI_VENDOR_YAMAHA, "Yamaha"},
     {PCI_VENDOR_SMI,	"Silicon Motion Inc."},
+    {PCI_VENDOR_VMWARE,	"VMware"},
     {0,NULL}
 };
 #endif
@@ -806,11 +870,13 @@ static pciVendorDeviceInfo xf86PCIVendorInfoData[] = {
 				{PCI_CHIP_RAGE128ML,	"Rage 128 Mobility ML",0},
 				{PCI_CHIP_RAGE128PD,	"Rage 128 Pro PD",0},
 				{PCI_CHIP_RAGE128PF,	"Rage 128 Pro PF",0},
+				{PCI_CHIP_RAGE128PP,	"Rage 128 Pro PP",0},
 				{PCI_CHIP_RAGE128PR,	"Rage 128 Pro PR",0},
 				{PCI_CHIP_RADEON_QD,	"Radeon QD",0},
 				{PCI_CHIP_RADEON_QE,	"Radeon QE",0},
 				{PCI_CHIP_RADEON_QF,	"Radeon QF",0},
 				{PCI_CHIP_RADEON_QG,	"Radeon QG",0},
+				{PCI_CHIP_RADEON_VE,	"Radeon VE",0},
 				{PCI_CHIP_RAGE128RE,	"Rage 128 RE",0},
 				{PCI_CHIP_RAGE128RF,	"Rage 128 RF",0},
 				{PCI_CHIP_RAGE128RK,	"Rage 128 RK",0},
@@ -854,7 +920,7 @@ static pciVendorDeviceInfo xf86PCIVendorInfoData[] = {
     {PCI_VENDOR_DIGITAL, {
 				{PCI_CHIP_DEC21030,	"21030/TGA",0},
 				{0x0001,		"DC21050 PCI-PCI Bridge"
-						 /* print_pcibridge} */,0 },
+						 /* print_pcibridge */,0 },
 				{0x0002,		"DC21040 10Mb/s Ethernet",0 },
 				{0x0009,		"DC21140 10/100 Mb/s Ethernet",0 },
 				{0x000D,		"TGA2",0 },
@@ -919,6 +985,8 @@ static pciVendorDeviceInfo xf86PCIVendorInfoData[] = {
 				{PCI_CHIP_9750,		"3DImage975",0},
 				{PCI_CHIP_9850,		"3DImage985",0},
 				{PCI_CHIP_9880,		"Blade3D",0},
+				{PCI_CHIP_9910,		"Cyber/BladeXP",0},
+				{PCI_CHIP_9930,		"CyberBlade/XPm",0},
 				{PCI_CHIP_8400,		"CyberBlade/i7",0},
 				{PCI_CHIP_8420,		"CyberBlade/DSTN/i7",0},
 				{PCI_CHIP_8500,		"CyberBlade/i1",0},
@@ -976,6 +1044,7 @@ static pciVendorDeviceInfo xf86PCIVendorInfoData[] = {
 				{PCI_CHIP_SIS300,	"300",0},
 				{PCI_CHIP_SIS630,	"630",0},
 				{PCI_CHIP_SIS540,	"540",0},
+				{PCI_CHIP_SIS82C204,    "82C204",0},
 				{0x0000,		NULL,0}}},
 #ifdef VENDOR_INCLUDE_NONVIDEO
      {PCI_VENDOR_HP, {
@@ -1208,35 +1277,76 @@ static pciVendorDeviceInfo xf86PCIVendorInfoData[] = {
 				{0x0000,		NULL,0}}},
 #endif
     {PCI_VENDOR_NVIDIA,	{
-				{PCI_CHIP_NV1,		"NV1",0},
-				{PCI_CHIP_DAC64,	"DAC64",0},
-				{PCI_CHIP_TNT,		"Riva TNT",0},
-				{PCI_CHIP_TNT2,		"Riva TNT2",0},
-				{PCI_CHIP_UTNT2,	"Riva Ultra TNT2",0},
-				{PCI_CHIP_VTNT2,	"Riva Vanta",0},
-				{PCI_CHIP_UVTNT2,	"Riva Ultra 64",0},
-                                {PCI_CHIP_TNT2_A,       "Riva TNT2 (A)",0},
-                                {PCI_CHIP_TNT2_B,       "Riva TNT2 (B)",0},
-				{PCI_CHIP_ITNT2,	"Riva Integrated",0},
-				{PCI_CHIP_GEFORCE256,	"GeForce 256",0},
-				{PCI_CHIP_GEFORCEDDR,	"GeForce DDR",0},
-				{PCI_CHIP_QUADRO,	"Quadro",0},
-				{PCI_CHIP_GEFORCE2MX,	"GeForce2 MX",0},
-				{PCI_CHIP_GEFORCE2MXDDR,"GeForce2 MX DDR",0},
-				{PCI_CHIP_QUADRO2MXR,	"GeForce2 MXR",0},
-				{PCI_CHIP_GEFORCE2GTS,	"GeForce2 GTS",0},
-				{PCI_CHIP_GEFORCE2GTS_1,"GeForce2 GTS (rev 1)",0},
-				{PCI_CHIP_GEFORCE2ULTRA,"GeForce2 Ultra",0},
-				{PCI_CHIP_QUADRO2PRO,	"Quadro 2 Pro",0},
-                                {PCI_CHIP_GEFORCE3,     "GeForce3",0},
-                                {PCI_CHIP_GEFORCE3_1,   "GeForce3 (rev 1)",0},
-                                {PCI_CHIP_GEFORCE3_2,   "GeForce3 (rev 2)",0},
-                                {PCI_CHIP_GEFORCE3_3,   "GeForce3 (rev 3)",0},
+	{PCI_CHIP_NV1,			"NV1",0},
+	{PCI_CHIP_DAC64,		"DAC64",0},
+	{PCI_CHIP_TNT,			"Riva TNT",0},
+	{PCI_CHIP_TNT2,			"Riva TNT2",0},
+	{PCI_CHIP_UTNT2,		"Riva Ultra TNT2",0},
+	{PCI_CHIP_VTNT2,		"Riva Vanta",0},
+	{PCI_CHIP_UVTNT2,		"Riva Ultra 64",0},
+	{PCI_CHIP_TNT2_A,		"Riva TNT2 (A)",0},
+	{PCI_CHIP_TNT2_B,		"Riva TNT2 (B)",0},
+	{PCI_CHIP_ITNT2,		"Riva Integrated",0},
+	{PCI_CHIP_GEFORCE256,		"GeForce 256",0},
+	{PCI_CHIP_GEFORCEDDR,		"GeForce DDR",0},
+	{PCI_CHIP_QUADRO,		"Quadro",0},
+	{PCI_CHIP_GEFORCE2MX,		"GeForce2 MX",0},
+	{PCI_CHIP_GEFORCE2MXDDR,	"GeForce2 MX DDR",0},
+	{PCI_CHIP_GEFORCE2GO,		"GeForce2 Go",0},
+	{PCI_CHIP_QUADRO2MXR,		"GeForce2 MXR",0},
+	{PCI_CHIP_GEFORCE2GTS,		"GeForce2 GTS",0},
+	{PCI_CHIP_GEFORCE2TI,	        "GeForce2 Ti",0},
+	{PCI_CHIP_GEFORCE2ULTRA,	"GeForce2 Ultra",0},
+	{PCI_CHIP_QUADRO2PRO,		"Quadro 2 Pro",0},
+	{PCI_CHIP_GEFORCE4MX_460,	"GeForce4 MX 460",0},        
+	{PCI_CHIP_GEFORCE4MX_440,	"GeForce4 MX 440",0},     
+	{PCI_CHIP_GEFORCE4MX_420,	"GeForce4 MX 420",0},     
+        {PCI_CHIP_GEFORCE4MX_440SE,     "GeForce4 MX 440-SE",0},
+	{PCI_CHIP_GEFORCE4GO_440,	"GeForce4 440 Go",0},     
+	{PCI_CHIP_GEFORCE4GO_420,	"GeForce4 420 Go",0},     
+	{PCI_CHIP_GEFORCE4GO_420_32M,	"GeForce4 420 Go 32M",0},     
+	{PCI_CHIP_GEFORCE4GO_460,	"GeForce4 460 Go",0},
+	{PCI_CHIP_QUADRO4XGL_500,	"Quadro4 500XGL",0}, 
+	{PCI_CHIP_GEFORCE4GO_440_64M,	"GeForce4 440 Go 64M",0},      
+	{PCI_CHIP_QUADRO4NVS,		"Quadro4 200/400NVS",0}, 
+	{PCI_CHIP_QUADRO4XGL_550,	"Quadro4 550XGL",0},  
+	{PCI_CHIP_QUADRO4GOGL_500,	"Quadro4 500 GoGL",0},      
+	{PCI_CHIP_GEFORCE4GO_410_16M,	"GeForce4 410 Go 16M",0},
+	{PCI_CHIP_GEFORCE4MX_440_AGP8X,	"GeForce4 MX 440 with AGP8X",0},
+	{PCI_CHIP_GEFORCE4MX_440SE_AGP8X,"GeForce4 MX 440SE with AGP8X",0},
+	{PCI_CHIP_GEFORCE4MX_420_AGP8X,	"GeForce4 MX 420 with AGP8X",0},
+	{PCI_CHIP_QUADRO4_XGL_580,	"Quadro4 580 XGL",0},
+	{PCI_CHIP_QUADRO4_NVS_280,	"Quadro4 280 NVS",0},
+	{PCI_CHIP_QUADRO4_XGL_380,	"Quadro4 380 XGL",0},
+	{PCI_CHIP_GEFORCE2GPU,		"GeForce2 Integrated GPU",0},
+	{PCI_CHIP_GEFORCE4GPU,		"GeForce4 MX Integrated GPU",0},
+	{PCI_CHIP_GEFORCE3,		"GeForce3",0},
+	{PCI_CHIP_GEFORCE3TI_200,	"GeForce3 Ti 200",0},
+	{PCI_CHIP_GEFORCE3TI_500,	"GeForce3 Ti 500",0},
+        {PCI_CHIP_QUADRO_DDC,		"Quadro DDC",0},
+	{PCI_CHIP_GEFORCE4TI_4600,	"GeForce4 Ti 4600",0},
+	{PCI_CHIP_GEFORCE4TI_4400,	"GeForce4 Ti 4400",0},    
+	{PCI_CHIP_GEFORCE4TI_4200,	"GeForce4 Ti 4200",0},    
+	{PCI_CHIP_QUADRO4XGL_900,	"Quadro4 900XGL",0},    
+	{PCI_CHIP_QUADRO4XGL_750,	"Quadro4 750XGL",0},      
+	{PCI_CHIP_QUADRO4XGL_700,	"Quadro4 700XGL",0},      
+	{PCI_CHIP_GEFORCE4TI_4800,	"GeForce4 Ti 4800",0}, 
+	{PCI_CHIP_GEFORCE4TI_4200_AGP8X,"GeForce4 Ti 4200 with AGP8X",0},
+	{PCI_CHIP_GEFORCE4TI_4800SE,	"GeForce4 Ti 4800 SE",0},
+	{PCI_CHIP_GEFORCE4GO_4200,	"GeForce4 4200 Go",0},
+	{PCI_CHIP_QUADRO4XGL_980,	"Quadro4 980 XGL",0},
+	{PCI_CHIP_QUADRO4XGL_780,	"Quadro4 780 XGL",0},
+	{PCI_CHIP_QUADRO4GOGL_700,	"Quadro4 700 GoGL",0},
+	{PCI_CHIP_GEFORCE3_MCPX,	"GeForce3 Integrated MCPX GPU",0},
+	{0x0000,			NULL,0}}},
+    {PCI_VENDOR_IMS, {
+				{PCI_CHIP_IMSTT128,	"TwinTurbo 128", 0},
+				{PCI_CHIP_IMSTT3D,	"TwinTurbo 3D", 0},
+#ifdef VENDOR_INCLUDE_NONVIDEO
+                                {0x8849, "8849",0 },
+#endif
 				{0x0000,		NULL,0}}},
 #ifdef VENDOR_INCLUDE_NONVIDEO
-    {PCI_VENDOR_IMS, {
-                                {0x8849, "8849",0 },
-				{0x0000,		NULL,0}}},
     {PCI_VENDOR_TEKRAM, {
                                 {0x690C, "DC690C",0 },
 				{0x0000,		NULL,0}}},
@@ -1392,9 +1502,14 @@ static pciVendorDeviceInfo xf86PCIVendorInfoData[] = {
 				{PCI_CHIP_GAMMA,	"GLINT Gamma",0},
 				{PCI_CHIP_PERMEDIA2V,	"GLINT Permedia 2v",0},
 				{PCI_CHIP_PERMEDIA3,	"GLINT Permedia 3",0},
+				{PCI_CHIP_PERMEDIA4,	"GLINT Permedia 4",0},
+				{PCI_CHIP_R4,		"GLINT R4",0},
+				{PCI_CHIP_R4ALT,	"GLINT R4 (Alt)",0},
+				{PCI_CHIP_GAMMA2,	"GLINT Gamma 2",0},
 				{0x0000,		NULL,0}}},
     {PCI_VENDOR_AVANCE_2, {
 				{PCI_CHIP_ALG2064,	"ALG2064",0},
+				{PCI_CHIP_ALG2501,	"ALG2501",0},
 				{0x0000,		NULL,0}}},
     {PCI_VENDOR_S3,	{
 				{PCI_CHIP_PLATO,	"PLATO/PX",0},
@@ -1431,6 +1546,7 @@ static pciVendorDeviceInfo xf86PCIVendorInfoData[] = {
 				{PCI_CHIP_968,		"968",0},
 				{0x0000,		NULL,0}}},
     {PCI_VENDOR_INTEL,{
+#ifdef VENDOR_INCLUDE_NONVIDEO
                                 {0x0482, "82375EB pci-eisa bridge",0},
 				{0x0483, "82424ZX cache dram controller",0},
 				{0x0484, "82378IB/ZB pci-isa bridge",0x0601},
@@ -1470,15 +1586,20 @@ static pciVendorDeviceInfo xf86PCIVendorInfoData[] = {
 				{0x71a2, "82443GX Host (no AGP)",0},
 				{0x84C4, "P6",0},
 				{0x84C5, "82450GX20",0},
+#endif
+#ifdef VENDOR_INCLUDE_NONVIDEO
 				{PCI_CHIP_I740_AGP,	"i740 (AGP)",0},
-				{PCI_CHIP_I815_BRIDGE,	"i815 Bridge",0},
-				{PCI_CHIP_I815,		"i815",0},
 				{PCI_CHIP_I810_BRIDGE,	"i810 Bridge",0},
-				{PCI_CHIP_I810,		"i810",0},
 				{PCI_CHIP_I810_DC100_BRIDGE,	"i810-dc100 Bridge",0},
-				{PCI_CHIP_I810_DC100,	"i810-dc100",0},
 				{PCI_CHIP_I810_E_BRIDGE,"i810e Bridge",0},
+				{PCI_CHIP_I815_BRIDGE,	"i815 Bridge",0},
+#endif
+
+				{PCI_CHIP_I810,		"i810",0},
+				{PCI_CHIP_I810_DC100,	"i810-dc100",0},
 				{PCI_CHIP_I810_E,	"i810e",0},
+				{PCI_CHIP_I815,		"i815",0},
+				{PCI_CHIP_I830,		"i830",0},
 				{0x0000,		NULL,0}}},
     {PCI_VENDOR_ADAPTEC, {
 				{0x0010, "2940U2",0 },
@@ -1524,6 +1645,10 @@ static pciVendorDeviceInfo xf86PCIVendorInfoData[] = {
 				{PCI_CHIP_SMI712,	"LynxEM+",0},
 				{PCI_CHIP_SMI720,	"Lynx3DM",0},
 				{0x0000,		NULL,0}}},
+    {PCI_VENDOR_VMWARE, {
+    				{PCI_CHIP_VMWARE0405,	"PCI SVGA (FIFO)",0},
+    				{PCI_CHIP_VMWARE0710,	"LEGACY SVGA",0},
+				{0x0000,		NULL,0}}},
     {0x0000, {
 				{0x0000,		NULL,0}}},
 };
@@ -1581,14 +1706,14 @@ static pciVendorCardInfo xf86PCICardInfoData[] = {
                         { 0x0000, (char *)NULL,0, NF } } },
 #endif
 	{ PCI_VENDOR_SONY, {
-						{ 0x8051, "Vaio Video",0,NF },
+			{ 0x8051, "Vaio Video",0,NF },
 #ifdef VENDOR_INCLUDE_NONVIDEO
-						{ 0x8052, "Vaio Audio",0,NF },
-						{ 0x8054, "Vaio Firewire",0,NF },
-						{ 0x8056, "Vaio Modem",0,NF },
-						{ 0x8057, "Vaio Ethernet",0,NF },
+			{ 0x8052, "Vaio Audio",0,NF },
+			{ 0x8054, "Vaio Firewire",0,NF },
+			{ 0x8056, "Vaio Modem",0,NF },
+			{ 0x8057, "Vaio Ethernet",0,NF },
 #endif
-						{ 0x0000, (char *)NULL,0, NF } } },
+			{ 0x0000, (char *)NULL,0, NF } } },
 	{ PCI_VENDOR_DIAMOND, {
                         { 0x0003, "Monster Fusion",0, NF },
 			{ 0x00b8, "Fire GL1",0, NF },
@@ -1607,6 +1732,35 @@ static pciVendorCardInfo xf86PCICardInfoData[] = {
 			{ 0x8760, "Fireport 40 Dual",0, NF },
                         { 0x8a10, "Stealth 3D 4000",0, NF },
                         { 0x0000, (char *)NULL,0, NF } } },
+	{ PCI_VENDOR_APPIAN, {
+                        { 0x3d32, "Jeronimo 2000",0, NF },
+                        { 0x3db3, "Jeronimo Pro",0, NF },
+                        { 0x0000, (char *)NULL,0, NF } } },
+	{ PCI_VENDOR_3DFX, {
+                        { PCI_CARD_VOODOO3_2000, "Voodoo3 2000",0, NF },
+                        { PCI_CARD_VOODOO3_3000, "Voodoo3 3000",0, NF },
+                        { 0x0000, (char *)NULL,0, NF } } },
+	{ PCI_VENDOR_3DLABS, {
+                        { 0x0096, "Permedia",0, NF },
+                        { 0x0098, "PermediaNT",0, NF },
+                        { 0x0099, "PermediaLC",0, NF },
+                        { 0x0100, "Permedia2 PCI",0, NF },
+                        { 0x0101, "Permedia2 AGP",0, NF },
+                        { 0x0102, "Oxygen GMX2000 PCI",0, NF },
+                        { 0x0106, "Oxygen GMX2000 AGP",0, NF },
+                        { 0x0116, "Oxygen GVX1 AGP",0, NF },
+                        { 0x0121, "Oxygen VX1 PCI",0, NF },
+                        { 0x0122, "Oxygen ACX AGP",0, NF },
+                        { 0x0123, "Oxygen ACX PCI",0, NF },
+                        { 0x0125, "Oxygen VX1 AGP",0, NF },
+                        { 0x0127, "Permedia3 Create!",0, NF },
+                        { 0x0134, "Oxygen GVX1 PCI",0, NF },
+                        { 0x0136, "Oxygen GVX210 AGP",0, NF },
+                        { 0x0140, "Oxygen VX1-16 AGP",0, NF },
+                        { 0x0144, "Oxygen VX1-4X AGP",0, NF },
+                        { 0x0400, "Oxygen GVX420 AGP",0, NF },
+                        { 0x0800, "Oxygen VX1-1600SW PCI",0, NF },
+                        { 0x0000, (char *)NULL,0, NF } } },
 	{ PCI_VENDOR_ELSA, {
                         { 0x0914, "Winner 1000",0, NF },
                         { 0x0930, "Winner 1000PRO 864",0, NF },
@@ -1726,6 +1880,12 @@ static pciVendorCardInfo xf86PCICardInfoData[] = {
 	{ PCI_VENDOR_NETGEAR, {
 			{ 0xf004, "FA310-TX Rev. D2",0, NF },
                         { 0x0000, (char *)NULL,0, NF } } },
+#endif
+#if 0
+	{ PCI_VENDOR_VMWARE, {
+    			{PCI_CHIP_VMWARE0405,	"PCI SVGA (FIFO)",0, NF },
+    			{PCI_CHIP_VMWARE0710,	"LEGACY SVGA",0, NF },
+			{0x0000,		NULL,0, NF } } },
 #endif
 	{0x0000, {
 	  		{0x0000,  NULL,0, NF } } },
